@@ -349,10 +349,9 @@ def go(batch=False):
                    os.path.join(home_path, AGENT_NAME))
 
         newenv['whatap.enabled'] = 'True'
-        def preexec_function():
-            signal.signal(signal.SIGINT, signal.SIG_IGN)
+        
         process = subprocess.Popen('./{0}'.format(AGENT_NAME),
-                                   cwd=home_path,env=newenv, preexec_fn=preexec_function)
+                                   cwd=home_path,env=newenv)
         # Write PID file
         write_file(home, file_name, str(process.pid))
     except Exception as e:
