@@ -22,3 +22,6 @@ class PacketTypeEnum(object):
 
     TX_PARAM = 30
     ACTIVE_STACK = 40
+    ACTIVE_STATS = 41
+
+    EVENT = 50
