@@ -50,17 +50,21 @@ def trace_handler(fn, start=False):
                 return fn(*args, **kwargs)
             
             # check raise step error
-            if ctx and ctx.error_step:
-                end_interceptor(ctx=ctx)
-                raise Exception(ctx.error_step)
-            
+            # if ctx and ctx.error_step:
+            #     end_interceptor(ctx=ctx)
+            #     raise Exception(ctx.error_step)
+
             try:
                 callback = func(*args, **kwargs)
             except Exception as e:
+                if ctx and ctx.error_step ==e:
+                    raise ctx.error_step
                 logging.debug(e, extra={'id': 'WA917'}, exc_info=True)
                 print(e, dict(extra={'id': 'WA917'}, exc_info=True))
                 return fn(*args, **kwargs)
             else:
+                if ctx and ctx.error_step:
+                    raise ctx.error_step
                 return callback
         
         return wrapper
@@ -159,39 +163,45 @@ def interceptor(rn_environ, *args, **kwargs):
 
     start_interceptor(ctx)
     
-    callback = fn(*args, **kwargs)
-    ctx = TraceContextManager.getLocalContext()
-    if ctx:
-        query_string = environ.get('QUERY_STRING', '')
-        if query_string:
-            ctx.service_name += '?{}'.format(query_string)
-
-        if ctx.service_name.find('.') > -1 and ctx.service_name.split('.')[
-            1] in conf.web_static_content_extensions:
-            ctx.isStaticContents = 'true'
-
-        if getattr(callback, 'status_code', None):
-            status_code = callback.status_code
-            errors = [callback.reason_phrase, callback.__class__.__name__]
-            interceptor_error(status_code, errors)
+    try:
         
-        if conf.profile_http_header_enabled:
-            keys = []
-            for key, value in environ.items():
-                if key.startswith('HTTP_'):
-                    keys.append(key)
-            keys.sort()
+        callback = fn(*args, **kwargs)
+        ctx = TraceContextManager.getLocalContext()
+        if ctx:
+            query_string = environ.get('QUERY_STRING', '')
+            if query_string:
+                ctx.service_name += '?{}'.format(query_string)
+
+            if ctx.service_name.find('.') > -1 and ctx.service_name.split('.')[
+                1] in conf.web_static_content_extensions:
+                ctx.isStaticContents = 'true'
+
+            if getattr(callback, 'status_code', None):
+                status_code = callback.status_code
+                errors = [callback.reason_phrase, callback.__class__.__name__]
+                interceptor_error(status_code, errors)
             
-            text = ''
-            for key in keys:
-                text += '{}={}\n'.format(key.split('HTTP_')[1].lower(),
-                                         environ[key])
-            
-            datas = ['HTTP-HEADERS', 'HTTP-HEADERS', text]
-            ctx.start_time = DateUtil.nowSystem()
-            UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
-        end_interceptor(ctx=ctx)
-    return callback
+            if conf.profile_http_header_enabled:
+                keys = []
+                for key, value in environ.items():
+                    if key.startswith('HTTP_'):
+                        keys.append(key)
+                keys.sort()
+                
+                text = ''
+                for key in keys:
+                    text += '{}={}\n'.format(key.split('HTTP_')[1].lower(),
+                                            environ[key])
+                
+                datas = ['HTTP-HEADERS', 'HTTP-HEADERS', text]
+                ctx.start_time = DateUtil.nowSystem()
+                UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
+            return callback
+    finally:
+        ctx = TraceContextManager.getLocalContext()
+        if ctx:
+            end_interceptor(ctx=ctx)
+    
 
 
 def interceptor_error(status_code, errors):
